#ifndef PARAMS_HH
#define PARAMS_HH
/*
  Parameter for Aligner
*/

class AlignerParams {  
public:
    const int match_score;
    const int mismatch_score;
    const int indel_score;

    const int tau_factor; // contribution of sequence similarity in an arc match (in percent)
  
    const bool no_lonely_pair; // no lonely pairs option
  
    const bool STRUCT_LOCAL; // allow exclusions for maximizing alignment of connected substructures 
    const bool SEQU_LOCAL; // maximize alignment of subsequences
  
    const bool DO_TRACE;
    
    const int exclusion_score; // Cost/similarity contribution per exclusion
  
    const int max_diff;

    const int max_diff_am;
    
    const std::vector<bool> &ungappedA;

    const int stacking;
    
    AlignerParams(int _match_score,int _mismatch_score,int _indel_score, int _tau_factor,
		  bool _no_lonely_pair, bool _STRUCT_LOCAL, 
		  bool _SEQU_LOCAL,
		  int _exclusion_score, int _max_diff, int _max_diff_am,
		  const std::vector<bool> &_ungappedA,
		  bool _stacking=false):
	match_score(_match_score),
	mismatch_score(_mismatch_score),
	indel_score(_indel_score),
	tau_factor(_tau_factor),
	no_lonely_pair(_no_lonely_pair),
	STRUCT_LOCAL(_STRUCT_LOCAL),
	SEQU_LOCAL(_SEQU_LOCAL),
	DO_TRACE(true),
	exclusion_score(_exclusion_score),
	max_diff(_max_diff),
	max_diff_am(_max_diff_am),
	ungappedA(_ungappedA),
	stacking(_stacking)
    {}
  
};


/*!
  parameters for the basepairs class

  contains the necessary information for determining the
  significant basepairs and computing their weights
*/
class BasePairsParams {
public:
    const int structure_weight; //!< weight for balancing structure contribution to sequence contribution in the score
	
    double prob_exp_f(int seqlen) const {return 1.0/(2.0*seqlen);} //!<expected probability of a base pair (null-model)
	
    const double min_prob; //!< only pairs with a probability of at least min_prob are taken into account
    const double exp_prob; //!< expected probability
    const bool opt_exp_prob;

    BasePairsParams(int _structure_weight,
		    double _min_prob,
		    double _exp_prob,
		    bool _opt_exp_prob)
      :
	structure_weight(_structure_weight),
	min_prob(_min_prob), exp_prob(_exp_prob),
	opt_exp_prob(_opt_exp_prob)
    {}
};

#endif // PARAMS_HH
